Biblioteca para tranformar os dados da função input de string para números inteiros.

Instruções de uso: primeiramente instale a biblioteca pelo pip usando o comando no powershell "pip install nummyint", logo após chame a biblioteca através do comando "nummyint"

Para utilizar a biblioteca chame a função obter_numero_inteiro.

Obrigado.